import React, { Component } from 'react';

import { ImagePicker, Modal } from 'antd-mobile';
import { isIOS } from '@/utils/tools';
import storage from '@/utils/storage.plugin';
import { PhotoSwipeGallery } from 'react-photoswipe';
import * as qiniu from 'qiniu-js';
import API from './api';
import 'react-photoswipe/lib/photoswipe.css';

class UpLoad extends Component {
  state = {
    isOpen: false,
    maxSelectImageNumber: 1, //上传文件数
    // certificateFiles: [],
    ViewImagesIndex: 0,
    appInfo: null
    // viewImages: [] //查看大图list
  };
  componentDidMount() {
    this.setState({
      appInfo: storage.getSS('appInfo')
    });
  }
  // 获取随机字符串
  random_string(len = 32) {
    let chars = 'ABCDEFGHJKMNPQRSTWXYZabcdefhijkmnprstwxyz2345678';
    let maxPos = chars.length;
    let pwd = '';
    for (let i = 0; i < len; i++) {
      pwd += chars.charAt(Math.floor(Math.random() * maxPos));
    }
    return pwd;
  }

  // 得到后缀名
  get_suffix(filename) {
    let pos = filename.lastIndexOf('.');
    let suffix = '';
    if (pos != -1) {
      suffix = filename.substring(pos);
    }
    return suffix;
  }

  // 推测文件随机名
  calculate_object_name(filename) {
    let suffix = this.get_suffix(filename);
    let g_object_name = this.random_string(10) + suffix;

    return g_object_name;
  }

  fileUploadQN(file) {
    let _this = this;
    let fileName = this.calculate_object_name(file.name);
    let putExtra = {
      fname: file.name,
      params: {},
      mimeType: ['image/png', 'image/jpeg', 'image/jpg']
    };
    let config = {
      useCdnDomain: true,
      region: qiniu.region.z0
    };
    let observer = {
      next(res) {
        _this.qiniuNext.call(_this, res);
      },
      error(err) {
        _this.qiniuError.call(_this, err);
      },
      complete(res) {
        _this.qiniuComplete.call(_this, res);
      }
    };
    API.nodeQiniuFile().then(res => {
      let observable = qiniu.upload(file, fileName, res.data, putExtra, config);
      observable.subscribe(observer);
    });
  }
  qiniuNext(res) {
    // console.log("qiniuNext >>>>>>>")
  }
  qiniuError(err) {
    this.props.refresh({
      code: -1,
      data: err
    });
  }
  qiniuComplete(res) {
    this.props.refresh({
      code: 0,
      data: res
    });
  }
  //点击图片
  onImageClickFun = (index, files) => {
    this.setState({
      ViewImagesIndex: index,
      isOpen: true
    });
  };
  //上传成功后或者删除
  certificateChange = (certificateFiles, operationType, index) => {
    //上传七牛云
    if (operationType === 'add') {
      this.fileUploadQN(certificateFiles[0].file);
    } else {
      this.props.delFile(certificateFiles);
    }
  };
  //查看大图方法
  closePhoto = () => {
    this.setState({
      isOpen: false
    });
  };
  getThumbnailContent = item => <img src={item.thumbnail} width={80} height={80} alt="" />;

  render() {
    const { maxSelectImageNumber, isOpen } = this.state;
    const { certificateFiles, viewImages } = this.props;

    return (
      <div className="photo-wrap">
        <ImagePicker
          onAddImageClick={e => {
            let version = this.state.appInfo.v;
            let vk = Object.keys(this.state.appInfo).filter(item => {
              return item.indexOf('accessToken=') > -1;
            })[0];
            if (!!vk) {
              version = this.state.appInfo[vk];
            }
            if (version <= '2.2.50' && isIOS) {
              e.preventDefault();
              Modal.alert('您的APP版本太低，升级后可使用上传图片功能');
            }
          }}
          accept="image/png, image/jpeg, image/jpg"
          files={certificateFiles}
          onChange={this.certificateChange}
          onImageClick={this.onImageClickFun}
          selectable={certificateFiles.length < maxSelectImageNumber}
        />
        <PhotoSwipeGallery items={viewImages} isOpen={isOpen} thumbnailContent={this.getThumbnailContent} options={{ closeOnScroll: false }} onClose={this.closePhoto} />
      </div>
    );
  }
}

export default UpLoad;
