import React, { Component } from 'react';
import { List, Icon, Button, Toast } from 'antd-mobile';
import app from '../../static/js/native';
import fetch from '../../api/fetch';
import { getParameterByName } from '../../utils/common';
import storage from '../../utils/storage.plugin';
import classNames from 'classnames';

import '@/static/styles/deposit/deposit.less';

const Item = List.Item;

export default class DepositPay extends Component {
  constructor(props) {
    super(props);
    this.state = {
      depositList: [],
      depositAmount: 0, // 已经缴纳的钱
      needPayMoney: 0, // 还需要缴纳的钱
      needPayQuality: 0, // 质量保证金应该缴纳的钱
      isQualityType: false // 是不是质量保证金模块
    };
  }
  // 选中当前选项
  selectItem = index => {
    const { depositList, depositAmount } = this.state;
    depositList[index].isChecked = !depositList[index].isChecked;
    let maxAmount = this.findMaxAmout(depositList);
    this.setState({
      depositList,
      needPayMoney: maxAmount - depositAmount > 0 ? maxAmount - depositAmount : 0
    });
  };
  goToTarget = item => {
    if (item.name === '联系财务') {
      // toUid="1308164" 财务id; utype参数后台没解析；
      app().gotoOCChat({ utype: '1', toUid: '1308164' });
    } else if (item.url) {
      window.location.href = item.url;
    }
  };
  // 找到最大值,相当于计算属性
  findMaxAmout = depositList => {
    let maxAmout = 0;
    //找出对象中的最大值；
    let arr = [];
    depositList.forEach(item => {
      item.isChecked && arr.push(item.baseAmount);
    });
    if (arr.length > 0) {
      // 从大到小排序
      arr.sort((a, b) => b - a);
      maxAmout = arr[0];
    }
    return maxAmout;
  };
  submit = async () => {
    if (!this.state.isQualityType && !this.state.needPayMoney) {
      return Toast.info('请先选中缴纳项');
    }
    let depositCfgIds = [];
    this.state.depositList.forEach(item => {
      if (item.isChecked === true) {
        depositCfgIds.push(item.cateId);
      }
    });
    console.log(this.state);
    const data = {
      amount: this.state.needPayMoney
      // depositCfgIds: depositCfgIds
      // _csrf: '7fZck_W6wt7TObsKdtmItJWZV3mTJnlGmyj3CJJE1bGgwTP6jP-uhpYNwkAnofHcpfoSF-VcNCOsGtpP4i-a3A=='
    };
    fetch('createPay', {
      data,
      headers: {
        uid: this.state.userInfo.uid,
        accessToken: this.state.userInfo.accessToken
      },
      success: res => {
        let params = res.data;
        app().setExpParams('pay', params, 'ydl_app');
      }
    });
  };
  fetchData = async () => {
    fetch('depositCategory', {
      success: res => {
        this.setState({
          depositList: res.data
        });
      }
    });
  };
  componentWillMount() {
    const asPath = location.href;
    this.setState({
      needPayQuality: getParameterByName('needPayQuality') || 0,
      depositAmount: (getParameterByName('money') || 0) * 1,
      isQualityType: asPath.indexOf('needPayQuality') > -1
    });
  }

  componentDidMount() {
    const userInfo = storage.getSS('appInfo');
    this.setState({
      userInfo
    });
    if (!this.state.isQualityType) {
      if (!this.props.result || !this.props.result.depositList) {
        this.fetchData();
      } else {
        this.setState({
          depositList: this.props.result
        });
      }
    }
    // 动态修改backgroud的颜色；
    try {
      window.document.body.style.backgroundColor = '#f6f6f6';
    } catch (e) {
      console.log(e);
    }
  }
  componentWillUnmount() {
    window.document.body.style.backgroundColor = 'white';
  }
  render() {
    const result = this.state.depositList.length > 0 ? this.state : this.props;
    let { depositList } = result;
    let { depositAmount, needPayQuality, isQualityType } = this.state;
    let { needPayMoney, isQuality } = this.state;
    let title = isQuality ? '缴纳质量保证金' : '缴纳保证金';
    let extra = (item, hasSelect) => (
      <div className="dib">
        <div className="df aic">
          <span className="mr15 c24">
            ¥ {item.baseAmount} {item.isChecked}
          </span>
          {!hasSelect && (item && item.isChecked ? <Icon type="check-circle" size="sm" color="#3d9eff" /> : <span className="circle-empty" />)}
          {hasSelect && item && <Icon type="check-circle" size="sm" color="#cccccc" />}
        </div>
      </div>
    );

    let extra2 = needPayQuality => (
      <div className="dib">
        <div className="df aic">
          <span className="c24">¥ {needPayQuality}</span>
        </div>
      </div>
    );

    let lists = (canSpreadProject, title) => (
      <div className={classNames({ greyWrap: canSpreadProject })}>
        <div className="small">{title}</div>
        <List className="my-list">
          {depositList &&
            depositList.length > 0 &&
            depositList.map((item, index) => {
              if (canSpreadProject) {
                return (
                  depositAmount >= item.baseAmount && (
                    <Item extra={extra(item, true)} key={index}>
                      {item.cateName}
                    </Item>
                  )
                );
              }
              return (
                depositAmount < item.baseAmount && (
                  <Item
                    extra={extra(item)}
                    onClick={() => {
                      this.selectItem(index);
                    }}
                    key={index}
                  >
                    {item.cateName}
                  </Item>
                )
              );
            })}
        </List>
      </div>
    );
    return (
      <div className="bg-grey-bj deposit-wrap">
        {isQualityType ? (
          <div>
            <List className="my-list">
              <Item extra={extra2(needPayQuality, true)}>质量保证金</Item>
            </List>
          </div>
        ) : (
          <div>
            {depositAmount > 0 && lists(true, '已缴纳项目')}
            {lists(false, '*选择多项时，保证金按金额最高的一项缴纳')}
          </div>
        )}
        <div className="fixBottom">
          <div className="fz13 tac ptb20">
            点击缴纳保证金即代表您同意 <a href="/deposit/protocol">《保证金协议》</a>
          </div>
          <Button type="primary" className="bdrs0" onClick={this.submit}>
            (¥ {isQualityType ? needPayQuality : needPayMoney}) 缴纳保证金
          </Button>
        </div>
        {/* <div className={"h100"}/> */}
      </div>
    );
  }
}
