import React, { Component } from 'react';
import { List, Icon, Toast } from 'antd-mobile';
import app from '../../static/js/native';
import Tips from '../../Components/common/Tips/Tips';
import fetch from '../../api/fetch';
import storage from '../../utils/storage.plugin';
import { getParameterByName } from '../../utils/common';

import '@/static/styles/deposit/deposit.less';

const Item = List.Item;

const lists = [
  {
    name: '资金明细',
    url: '/ex-index/fund'
  },
  {
    name: '联系财务'
  }
];

export default class DepositPay extends Component {
  state = {
    depositMoney: 0, //类目保证金
    qualityDepositMoney: 0, //质量保证金
    depositList: [], //可开展的业务
    depositAmountNeedPay: 0 //质量保证金待缴纳金额
  };
  goToTarget = item => {
    if (item.name === '联系财务') {
      // toUid="1308164" 财务id; utype参数后台没解析；
      app().gotoOCChat({ utype: '1', toUid: '1308164' });
    } else if (item.url) {
      window.location.href = item.url;
    }
  };
  fetchData = () => {
    fetch('myDeposit', {
      success: result => {
        let { cateDepositAmount, cateMeetRequired, qualityDepositAmount, qualityDepositDeficiency } = result.data;
        this.setState({
          depositMoney: cateDepositAmount, //类目保证金
          qualityDepositMoney: qualityDepositAmount, //质量保证金
          depositList: cateMeetRequired, //可开展的业务
          depositAmountNeedPay: qualityDepositDeficiency //质量保证金待缴纳金额
        });
      }
    });
  };
  // analysisQuery() {
  //   let search = location.search;
  //   if (!search) return null;
  //   search = search.substr(1).split('&');
  //   let obj = {};
  //   search.forEach(item => {
  //     let it = item.match(/(.+)=(.+)/);
  //     obj[it[1]] = it[2];
  //   });
  //   return obj;
  // }
  componentDidMount() {
    if (!this.props.result || !this.props.result.depositList) {
      this.fetchData();
    }
  }
  render() {
    let { depositMoney, qualityDepositMoney, depositList, depositAmountNeedPay } = this.state;
    return (
      <div className={'deposit-user'}>
        <Tips money={depositAmountNeedPay} />
        <div className="pt10 box-c tal">
          <b className="fs14 box-c">
            保证金总余额： <span className="blue fs18">{depositMoney + qualityDepositMoney}</span>
          </b>
        </div>
        <div className={'deposit-pannel'}>
          <div className={'deposit-pannel-item bdb1'}>
            <div className="fx1 tal">
              <div className={'fs17'}>
                <div className={'fs14'}>类目保证金余额（元）</div>
                <b className={'fs30'}>{depositMoney}</b>
              </div>
            </div>
            <div className={'tar'}>
              <span
                className={'button-primary'}
                onClick={() => {
                  window.location.href = `/new/deposit/Pay?money=${depositMoney}`;
                }}
              >
                去缴纳
              </span>
            </div>
          </div>
          <div className={'p20'}>
            <div className={'mb10'}>可展开服务</div>
            <div className={'tagsWrap'}>
              {depositList &&
                depositList.length > 0 &&
                depositList.map((item, index) => (
                  <span className={'tags'} key={index}>
                    {item}
                  </span>
                ))}
            </div>
            <div className="c9 fz11 pt10">*咨询师须缴纳类目保证金才能开展对应的服务</div>
          </div>
        </div>

        <div className={'deposit-pannel'}>
          <div className={'deposit-pannel-item'}>
            <div className="fx1">
              <div className={'fs17'}>
                <div className={'fs14'}>质量保证金余额（元）</div>
                <b className={'fs30'}>{qualityDepositMoney}</b>
              </div>
            </div>
            <div className={'tar'}>
              <span
                className={'button-primary'}
                onClick={() => {
                  window.location.href = `/new/deposit/Pay?needPayQuality=${depositAmountNeedPay}`;
                }}
              >
                去缴纳
              </span>
            </div>
          </div>
          <div className={'p20 pt0'}>
            <div className="c9 fz11 pt10">*当咨询师存在违规行为须缴纳质量保证金</div>
          </div>
        </div>
        <List className="my-list mt20">
          {lists &&
            lists.length > 0 &&
            lists.map((item, index) => {
              return (
                <Item
                  arrow="horizontal"
                  onClick={() => {
                    this.goToTarget(item);
                  }}
                  key={index}
                >
                  {item.name}
                </Item>
              );
            })}
        </List>
      </div>
    );
  }
}
