import React, { Component } from 'react';
import { Modal, Toast } from 'antd-mobile';
import classNames from 'classnames';
import { linkTo } from '@/utils/tools';
import TrainItem from '../../Components/page/user/TrainItem';
import TabBar from '../../Components/page/user/TabBar';
import { MATERIAL_ARR } from '../../static/js/constant';

import app from '../../static/js/native';
import fetch from '../../api/fetch';
import { getParameterByName } from '../../utils/common';

import '@/static/styles/user/train-list.less';

function AddView(props) {
  return (
    <div className="bottom-operate">
      <a
        className="am-button button-cover am-button-primary"
        onClick={() => {
          linkTo(`/new/user/job/add?index=${props.tabIndex}`);
        }}
      >
        添加{MATERIAL_ARR[props.tabIndex]}
      </a>
    </div>
  );
}
function NoDataView(props) {
  return (
    <a
      className="add-train"
      onClick={() => {
        linkTo(`/new/user/job/add?index=${props.tabIndex}`);
      }}
    >
      <i className="y-icon-add" />
      <span>添加{MATERIAL_ARR[props.tabIndex]}</span>
    </a>
  );
}
function ListItemView(props) {
  if (props.dataArr.length) {
    return (
      <React.Fragment>
        <ul className="train-list">
          {props.dataArr.map((item, index) => (
            <TrainItem iType={props.tabIndex} key={index} data={item} delToggle={props.delTrain} />
          ))}
        </ul>
        <AddView tabIndex={props.tabIndex} />
      </React.Fragment>
    );
  } else {
    return <NoDataView tabIndex={props.tabIndex} />;
  }
}

class JobList extends Component {
  constructor(props) {
    super(props);
    this.state = {
      authList: [],
      backList: [],
      honorList: [],
      delDialogObj: {
        //删除确认框
        isShow: false,
        title: '是否删除此条受训背景'
      },
      tabIndex: null
    };
  }
  componentWillMount() {
    document.title = '职业背景';
    this.setState({
      tabIndex: parseInt(getParameterByName('index', location.href)) || 0
    });
  }
  componentDidMount() {
    app().downRefresh(true);
    app().notRefresh(true);
    this.initData();
  }
  initData = () => {
    fetch('fetchJobList', {
      success: res => {
        this.setState({
          authList: res.data.doctorTeamCertification,
          backList: res.data.doctorRenZhiBackground,
          honorList: res.data.doctorHonoraryTitle
        });
      }
    });
  };
  filterMod(data) {
    return data.filter(item => item.auditStatus != '2');
  }
  tabToggle(index) {
    this.setState({
      tabIndex: index
    });
    const { history } = this.props;
    history.replace(`${history.location.pathname}?index=${index}`);
    // location.replace(`?index=${index}`);
  }
  toAddMaterial = () => {};
  delTrain = operate => {
    this.setState({
      delDialogObj: Object.assign({}, this.state.delDialogObj, operate, { isShow: true })
    });
  };

  subDel = () => {
    const { id, modifyId } = this.state.delDialogObj;
    let param = {};
    id != '0' && (param.deleteId = id * 1);
    modifyId != '0' && (param.modifyId = modifyId * 1);

    fetch(`delJob${this.state.delDialogObj.delType}`, {
      data: param,
      success: res => {
        // let oldArr;
        // if (this.state.delDialogObj.delType === 0) {
        //   oldArr = 'authList';
        // } else if (this.state.delDialogObj.delType === 1) {
        //   oldArr = 'backList';
        // } else if (this.state.delDialogObj.delType === 2) {
        //   oldArr = 'honorList';
        // }
        // console.log(this.state[oldArr], this.state.delDialogObj.id);
        // const newTrainList = this.state[oldArr].filter(item => item.id != this.state.delDialogObj.id);
        // this.setState({
        //   [oldArr]: newTrainList
        // });
        this.initData();
        this.onCloseDel();
        Toast.info('删除成功');
      }
    });
  };
  onCloseDel = () => {
    this.setState({
      delDialogObj: Object.assign({}, this.state.delDialogObj, { isShow: false })
    });
  };
  render() {
    const { authList, backList, honorList, delDialogObj, tabIndex } = this.state;
    // title="执业背景"
    return (
      <div>
        <TabBar tabTexts={MATERIAL_ARR} tabIndex={tabIndex} tabToggle={index => this.tabToggle(index)} />
        <div className="train-warp job-list-wrap">
          <div className="swiper-box">
            <div className={classNames('swiper-item', { active: tabIndex === 0 })}>
              <ListItemView dataArr={authList} tabIndex={tabIndex} delTrain={this.delTrain} />
            </div>
            <div className={classNames('swiper-item', { active: tabIndex === 1 })}>
              <ListItemView dataArr={backList} tabIndex={tabIndex} delTrain={this.delTrain} />
            </div>
            <div className={classNames('swiper-item', { active: tabIndex === 2 })}>
              <ListItemView dataArr={honorList} tabIndex={tabIndex} delTrain={this.delTrain} />
            </div>
          </div>

          <Modal
            footer={[
              {
                text: '点错了',
                onPress: () => {
                  this.onCloseDel();
                }
              },
              {
                text: '删除',
                onPress: () => {
                  this.subDel();
                }
              }
            ]}
            className="del-train-dialog"
            transparent
            maskClosable
            visible={delDialogObj.isShow}
            title={delDialogObj.title}
          />
        </div>
      </div>
    );
  }
}

export default JobList;
