import React, { Component } from 'react';
import { Toast, Modal } from 'antd-mobile';
import { MATERIAL_ARR } from '../../static/js/constant';
import { getParam, getImgNaturalDimensions, linkTo } from '../../utils/tools';
import UpLoad from '../../Components/common/Upload/Upload';
import { getParameterByName } from '../../utils/common';

import app from '../../static/js/native';
import classNames from 'classnames';
import fetch from '../../api/fetch';
import '@/static/styles/user/add-material.less';

const materialLabel = ['', '在社会或职场中所担任职位时所受到的头衔，需提供对应证明。', '市级及以上由政府各部门颁发的称号，需提供对应证明。'];
class AddMaterial extends Component {
  state = {
    backgroundArea: '', //说明文案
    materialType: null, //资料类型 ['0认证资质', '1任职背景', '2荣誉称号']
    imgUrls: [],
    certificateFiles: [],
    viewImages: [],
    isEdit: false, //是否是编辑
    hasChange: false, //是否编辑过
    isShowRange: false,
    modifyId: null,
    id: null
  };
  componentWillMount() {}
  componentDidMount() {
    app().downRefresh(false);
    app().notRefresh(false);
    const id = getParam(location.href);
    const index = getParameterByName('index') * 1; //修改类型
    const modifyId = getParameterByName('modifyId');
    if (index > 2 || index === null) {
      return Toast.info('路径有误');
    }
    document.title = MATERIAL_ARR[index];
    this.setState({
      isEdit: modifyId !== null,
      materialType: index,
      modifyId,
      id
    });
    if (modifyId !== null) {
      let queryArr = ['doctorTeamCertifications', 'doctorRenZhiBackgrounds', 'doctorHonoraryTitles'];
      let params = {
        tableType: queryArr[index]
      };
      id != '0' && (params.id = id);
      modifyId !== '0' && (params.modifyId = modifyId);

      fetch('queryData', {
        data: params,
        success: res => {
          this.setState({
            backgroundArea: res.data.info,
            imgUrls: [res.data.image]
          });
          this.initImgs([res.data.image]);
        }
      });
    }
  }

  initImgs = imgs => {
    let viewArr = [],
      creArr = [];
    const _this = this;
    imgs.forEach(item => {
      getImgNaturalDimensions(item, function(w, h) {
        viewArr.push({
          src: item,
          w: w,
          h: h
        });
        creArr.push({
          url: item
        });
        _this.setState({
          viewImages: viewArr
        });
      });
    });
    this.setState({ certificateFiles: creArr });
  };
  handleInputChange = event => {
    const { target } = event;
    const value = target.type === 'checkbox' ? target.checked : target.value;
    const { name } = target;
    this.setState({
      [name]: value
    });

    this.hansChangeForm();
  };
  refreshFile = res => {
    if (res.code >= 0) {
      this.setState(
        {
          imgUrls: [`https://imgqiniu.yidianling.com/${res.data.key}`]
        },
        () => {
          this.initImgs(this.state.imgUrls);
        }
      );
      this.hansChangeForm();
    } else {
      Toast.info('上传图片失败，请重试', 2);
    }
  };
  delFile = () => {
    this.setState({
      certificateFiles: []
    });
    this.hansChangeForm();
  };
  validateForm = () => {
    if (!this.state.backgroundArea) {
      return Toast.info(`请输入${MATERIAL_ARR[this.state.materialType]}`, 2);
    }
    return true;
  };

  hansChangeForm = () => {
    this.setState({ hasChange: true });
  };
  toggleRange = () => {
    this.setState({
      isShowRange: !this.state.isShowRange
    });
  };

  submitJob = () => {
    if (this.validateForm() !== true) return;
    Modal.alert('确认信息无误，提交审核', '', [
      {
        text: '取消'
      },
      {
        text: '确认',
        onPress: () => {
          let subType, str;
          let param = {
            info: this.state.backgroundArea,
            image: this.state.imgUrls.length ? this.state.imgUrls[0] : ''
          };
          if (this.state.isEdit) {
            subType = 'editJob';
            const { id, modifyId } = this.state;
            id != '0' && (param.id = id * 1);
            modifyId != '0' && (param.modifyId = modifyId * 1);
            str = '编辑';
          } else {
            subType = 'addJob';
            str = '添加';
          }
          fetch(`${subType}${this.state.materialType}`, {
            data: param,
            success: res => {
              Toast.info(`${str}成功`);
              fetch('fetchJobList', {
                loading: false
              });
              setTimeout(() => {
                history.back();
              }, 3000);
            }
          });
        }
      }
    ]);
  };
  render() {
    const { materialType, backgroundArea, certificateFiles, viewImages } = this.state;
    const materialStr = MATERIAL_ARR[materialType] || '';
    // title={materialStr}
    return (
      <div className="add-material">
        <div className="box-c pt20">
          <div className="mb5 rel">
            <span className="fs16 b">{materialStr}</span>
            {materialType === 0 && (
              <div onClick={this.toggleRange} className="tip-right">
                <span className="mr5">平台认证咨询师范围</span>
                <i className="y-icon-answer" />
              </div>
            )}
          </div>
          <div className="c9">{materialLabel[materialType]}</div>
          <div className="train-name mt10">
            <textarea className="yui-textarea" name="backgroundArea" value={backgroundArea} onChange={this.handleInputChange} placeholder={`建议一次添加一个${materialStr}`} rows="4" />
          </div>

          <div className="fs16 b mt30 mb5">上传证书图片</div>

          <div className="c-b3">证书信息真实，照片清晰可辨，信息完整无缺失，严禁经过ps处理（最多1张）</div>
          <UpLoad certificateFiles={certificateFiles} viewImages={viewImages} refresh={this.refreshFile} delFile={this.delFile} />
        </div>
        <div className="bottom-operate">
          <button disabled={this.state.isEdit && !this.state.hasChange} onClick={this.submitJob} className="am-button button-cover am-button-primary">
            提交
          </button>
        </div>

        <div className={classNames('y-dialog-wrap', { hide: !this.state.isShowRange })}>
          <div className="y-modal" />
          <div className="y-dialog dialog-intro">
            <div className="title" />
            <ul>
              <li>1.教师资格</li>
              <li>2.法律资格</li>
              <li>3.医师/药师相关</li>
              <li>4.护士</li>
              <li>5.母婴保健类</li>
              <li>6.健康管理师</li>
              <li>7.生殖健康咨询师</li>
              <li>8.保健调理师</li>
              <li>9.育婴员/保育员/孤残儿童护理员</li>
              <li>10.企业人力资源管理师</li>
              <li>11.社工类</li>
              <li>12.婚姻家庭咨询师</li>
            </ul>
            <div className="y-dialog-btn">
              <button onClick={this.toggleRange} className="am-button button-cover am-button-primary">
                确定
              </button>
            </div>
            <div onClick={this.toggleRange} className="y-dialog-close">
              <i className="y-icon-close-border" />
            </div>
          </div>
        </div>
      </div>
    );
  }
}
export default AddMaterial;
